Package 'sivs'

Title: Stable Iterative Variable Selection
Description: An iterative feature selection method that internally utilizes various Machine Learning methods that have embedded feature reduction in order to shrink down the feature space into a small and yet robust set.
Authors: Mehrad Mahmoudian [aut, cre] (ORCID: <https://orcid.org/0000-0001-7650-1862>), Mikko Venäläinen [aut, rev] (ORCID: <https://orcid.org/0000-0003-1777-4259>), Riku Klèn [aut, ths] (ORCID: <https://orcid.org/0000-0002-0982-8360>), Laura Elo [aut, ths, fnd] (ORCID: <https://orcid.org/0000-0001-5648-4532>)
Maintainer: Mehrad Mahmoudian <[email protected]>
License: GPL-3
Version: 0.2.11
Built: 2026-05-09 05:12:00 UTC
Source: https://github.com/mmahmoudian/sivs

Help Index